==> haskell-storable-complex-0.2.3.0-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-3faqpVwMEY94gT69yqO4iN
key:                  storable-complex-0.2.3.0-3faqpVwMEY94gT69yqO4iN
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  ba3b00f352a06e025a0a7397b0a843fe
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-8.10.2/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/storable-complex-0.2.3.0
hs-libraries:         HSstorable-complex-0.2.3.0-3faqpVwMEY94gT69yqO4iN
depends:
    base-4.14.1.0 base-orphans-0.8.3-8BvsxO6sDZOGKQ5IVzZGDx

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-LdMCljDpdOd77Im003Xm6c
key:                  storable-complex-0.2.3.0-LdMCljDpdOd77Im003Xm6c
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  18d0029adbc45e5e58eab73148dd9bd9
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-8.10.2/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/storable-complex-0.2.3.0
hs-libraries:         HSstorable-complex-0.2.3.0-LdMCljDpdOd77Im003Xm6c
depends:
    base-4.14.1.0 base-orphans-0.8.3-HPypaYVVpYqB17Nwsn2HIZ

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
